@@ -1,4 +1,29 @@
+import sys
+__main__ = sys.modules["__main__"]
 
+def test(args):
+    import Xponge
+    import Xponge.forcefield.AMBER.ff14SB
+    import Xponge.forcefield.AMBER.tip3p
+    
+    globals().update(__main__.__dict__)
+    
+    t = ACE + ALA * 10 + NME
+
+    for i in range(1,len(t.residues)-1):
+        head = t.residues[i-1]
+        res = t.residues[i]
+        tail = t.residues[i+1]
+        Impose_Dihedral(t, head.C, res.N, res.CA, res.C, -3.1415926/3)
+        Impose_Dihedral(t, res.N, res.CA, res.C, tail.N, -3.1415926/3)
+
+    Save_Mol2(t, f"{args.o}.mol2")
+    c = int(round(t.charge))
+    Process_Box(t, WAT, 10)
+    Ion_Replace(t, lambda res: res.type.name == "WAT", {CL:30 + c, K:30})
+    t.residues.sort(key = lambda residue: {"CL":2, "K":1, "WAT":3}.get(residue.type.name, 0))
+    Save_PDB(t, f"{args.o}.pdb")
+    Save_SPONGE_Input(t, f"{args.o}")
 
 def dat2nc(args):
     from struct import unpack
@@ -427,7 +452,7 @@ def mol2rfe(args):
     
     rmol = Xponge.LOAD.pdb(args.pdb)
 
-    merged_from, merged_to = FEP.Merge_Dual_Topology(rmol, rmol.residues[args.ri], _to_res_type, _from, _to)
+    merged_from, merged_to = FEP.Merge_Dual_Topology(rmol, rmol.residues[args.ri], _to_res_type, _from, _to, args.tmcs)
     
     if args.dohmr:
         Xponge.PROCESS.HMass_Repartition(merged_from)
@@ -458,20 +483,21 @@ def mol2rfe(args):
             else:
                 cif = ""
                 os.rename("0/{0}_LJ_soft_core.txt".format(args.temp), "0/{0}_lj_soft_core.txt".format(args.temp))
-                os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit 2000 {4} -mass_in_file {2}/{1}_fake_mass.txt -charge_in_file {2}/{1}_fake_charge.txt -LJ_in_file {2}/{1}_fake_LJ.txt".format(args.sponge, args.temp, i, i / args.nl, cif))
+                os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5} {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[0]))
                 cif = "-coordinate_in_file {1}/min/{0}_coordinate.txt".format(args.temp, i)
-                os.system("{0} -mode minimization -dt 1e-7 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit 2000  {4} -mass_in_file {2}/{1}_fake_mass.txt -charge_in_file {2}/{1}_fake_charge.txt -LJ_in_file {2}/{1}_fake_LJ.txt".format(args.sponge, args.temp, i, i / args.nl, cif))
-                os.system("{0} -mode minimization -dt 1e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit 2000  {4} -mass_in_file {2}/{1}_fake_mass.txt -charge_in_file {2}/{1}_fake_charge.txt -LJ_in_file {2}/{1}_fake_LJ.txt".format(args.sponge, args.temp, i, i / args.nl, cif))
-                os.system("{0} -mode minimization -dt 1e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit 2000  {4} -mass_in_file {2}/{1}_fake_mass.txt -charge_in_file {2}/{1}_fake_charge.txt -LJ_in_file {2}/{1}_fake_LJ.txt".format(args.sponge, args.temp, i, i / args.nl, cif))
-                os.system("{0} -mode minimization -dt 1e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit 2000  {4} -mass_in_file {2}/{1}_fake_mass.txt -charge_in_file {2}/{1}_fake_charge.txt -LJ_in_file {2}/{1}_fake_LJ.txt".format(args.sponge, args.temp, i, i / args.nl, cif))
+                os.system("{0} -mode minimization -dt 1e-7 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[1]))
+                os.system("{0} -mode minimization -dt 1e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[0]))
+                os.system("{0} -mode minimization -dt 1e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[1]))
+                os.system("{0} -mode minimization -dt 1e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[2]))
                 os.rename("0/{0}_lj_soft_core.txt".format(args.temp), "0/{0}_LJ_soft_core.txt".format(args.temp))
-                os.system("{0} -mode minimization -dt 2e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit 2000 -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif))
-                os.system("{0} -mode minimization -dt 2e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit 2000 -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif))
-                os.system("{0} -mode minimization -dt 2e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit 2000 -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif))
-                os.system("{0} -mode minimization -dt 2e-3 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit 3000 -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif))
+                os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} {4} constrain_mode SHAKE".format(args.sponge, args.temp, i, i / args.nl, cif, args.msteps[0]))
+                os.system("{0} -mode minimization -dt 1e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[0]))
+                os.system("{0} -mode minimization -dt 1e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[1]))
+                os.system("{0} -mode minimization -dt 1e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[2]))
+                os.system("{0} -mode minimization -dt 1e-3 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[3]))
 
-            os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit 3000 {4} constrain_mode SHAKE".format(args.sponge, args.temp, i, i / args.nl, cif))
-            os.system("{0} -mode minimization -dt 2e-3 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit 5000 -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif))
+            os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} {4} constrain_mode SHAKE".format(args.sponge, args.temp, i, i / args.nl, cif, args.msteps[0]))
+            os.system("{0} -mode minimization -dt 2e-3 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.msteps[1]))
 
     if "prebalance" in args.do:
         for i in range(args.nl + 1):
